<?php declare(strict_types=1);

namespace Everyware\Plugin\CacheInvalidator;

/**
 * Class LedgeInvalidator
 * @package Everyware\Plugin\CacheInvalidator
 */
class LedgeInvalidator
{

    /**
     * Invalidate given url via lua invalidation endpoint.
     *
     * @param $url
     * @param $streamId
     */
    public static function invalidateUrl($url, $streamId = ''): void
    {

        $response = wp_remote_post(get_site_url() . '/ledge-invalidate/', [
            'sslverify' => false,
            'headers' => [
                'User-Agent' => 'ew-ledge-invalidation',
            ],
            'body' => [
                'url' => $url
            ]
        ]);

        if (is_wp_error($response)) {
            PageEventLog::addEvent($url, $streamId, 'error');
            wp_send_json([
                'status' => $response->get_error_message()
            ]);
        }

        if ($response['response']['code'] === 200) {
            PageEventLog::addEvent($url, $streamId, 'success');
            wp_send_json([
                'status' => 'Success'
            ]);
        } elseif ($response['response']['code'] === 404) {
            PageEventLog::addEvent($url, $streamId, 'nothing to invalidate');
            wp_send_json([
                'status' => 'Found nothing to invalidate'
            ]);
        } else {
            PageEventLog::addEvent($url, $streamId, 'error');
            wp_send_json([
                'status' => 'Error'
            ]);
        }
    }
}
